<?php

/**************************************************************************\
* eGroupWare                                                               *
* http://www.egroupware.org                                                *
* --------------------------------------------                             *
*  This program is free software; you can redistribute it and/or modify it *
*  under the terms of the GNU General Public License as published by the   *
*  Free Software Foundation; either version 2 of the License, or (at your  *
*  option) any later version.                                              *
\**************************************************************************/

require_once('class.so_external_applications.inc.php');
require_once('class.bo_ajaxinterface.inc.php');
/**
 * Camada Business das Aplicaes Externas.
 * @package Workflow
 * @author Sidnei Augusto Drovetto Jr. - drovetto@gmail.com
 * @license http://www.gnu.org/copyleft/gpl.html GPL
 */
class bo_external_applications extends bo_ajaxinterface
{
	/**
	 * @var object Acesso  camada Model das Aplicaes Externas.
	 * @access private
	 */
	private $so;

	/**
	 * Construtor da classe so_orgchart
	 * @return object
	 */
	function bo_external_applications()
	{
		parent::bo_ajaxinterface();
		$this->so = new so_external_applications();
	}

	/**
	 * Lista todas as aplicaes externas
	 * @return array Lista de aplicaes externas
	 * @access public
	 */
	function getExternalApplications()
	{
		$result = $this->so->getExternalApplications();
		$this->disconnect_all();

		return $result;
	}

	/**
	 * Busca informaes sobre uma aplicao externa
	 * @param array $params Uma array contendo os parmetros necessrios para encontrar as informaes de uma aplicao externa (Ajax)
	 * @return bool TRUE se a ao foi concluda com xito e FALSE caso contrrio
	 * @access public
	 */
	function getExternalApplication($params)
	{
		$result = $this->so->getExternalApplication((int) $params['external_application_id']);
		$this->disconnect_all();

		return $result;
	}

	/**
	 * Adiciona uma aplicao externa
	 * @param array $params Uma array contendo os parmetros necessrios para adicionar uma aplicao externa (Ajax)
	 * @return bool TRUE se a ao foi concluda com xito e FALSE caso contrrio
	 * @access public
	 */
	function addExternalApplication($params)
	{
		$result = $this->so->addExternalApplication($params['name'], $params['description'], $params['address'], $params['image'], $params['authentication'], $params['post'], $params['intranet_only']);
		$this->disconnect_all();

		return $result;
	}

	/**
	 * Atualiza uma aplicao externa
	 * @param array $params Uma array contendo os parmetros necessrios para atualizar uma aplicao externa (Ajax)
	 * @return bool TRUE se a ao foi concluda com xito e FALSE caso contrrio
	 * @access public
	 */
	function updateExternalApplication($params)
	{
		$result = $this->so->updateExternalApplication($params['external_application_id'], $params['name'], $params['description'], $params['address'], $params['image'], $params['authentication'], $params['post'], $params['remove_current_image'], $params['intranet_only']);
		$this->disconnect_all();

		return $result;
	}

	/**
	 * Remove uma aplicao externa
	 * @param array $params Uma array contendo os parmetros necessrios para remover uma aplicao externa (Ajax)
	 * @return bool TRUE se a ao foi concluda com xito e FALSE caso contrrio
	 * @access public
	 */
	function removeExternalApplication($params)
	{
		$result = $this->so->removeExternalApplication((int) $params['external_application_id']);
		$this->disconnect_all();

		return $result;
	}
}
?>
